@@ -1,7 +1,7 @@
 /*
  *  Copyright (C) 2000,2001,2002 Nikos Mavroyanopoulos
  *
- * This file is part of GNUTLS.
+ *  This file is part of GNUTLS.
  *
  *  The GNUTLS library is free software; you can redistribute it and/or
  *  modify it under the terms of the GNU Lesser General Public   
@@ -19,6 +19,17 @@
  *
  */
 
+/* This file contains the types and prototypes for all the
+ * high level functionality of gnutls main library. For the
+ * extra functionality (which is under the GNU GPL license) check
+ * the gnutls/extra.h header. The openssl compatibility layer is
+ * in gnutls/openssl.h.
+ *
+ * The low level cipher functionality is in libgcrypt. Check
+ * gcrypt.h
+ */
+
+
 #ifndef GNUTLS_H
 # define GNUTLS_H
 
@@ -26,7 +37,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.6.0"
+#define LIBGNUTLS_VERSION "0.8.0"
 
 /* For backwards compatibility */
 #include <gnutls/compat4.h>
@@ -259,7 +270,7 @@ const char* gnutls_check_version( const char*);
 
 /* Functions for setting/clearing credentials 
  */
-int gnutls_clear_creds( gnutls_session session);
+int gnutls_credentials_clear( gnutls_session session);
 
 /* cred is a structure defined by the kx algorithm 
  */
@@ -440,6 +451,8 @@ void gnutls_certificate_server_set_request( gnutls_session, gnutls_certificate_r
 int gnutls_x509_certificate_to_xml(const gnutls_datum * cert, gnutls_datum* res, int detail);
 
 int gnutls_x509_extract_dn( const gnutls_datum*, gnutls_x509_dn*);
+int gnutls_x509_extract_dn_string(const gnutls_datum * idn,
+        char *buf, unsigned int sizeof_buf);
 int gnutls_x509_extract_certificate_dn( const gnutls_datum*, gnutls_x509_dn*);
 int gnutls_x509_extract_certificate_dn_string(char *buf, unsigned int sizeof_buf,
    const gnutls_datum * cert, int issuer);
@@ -451,6 +464,7 @@ time_t gnutls_x509_extract_certificate_expiration_time( const gnutls_datum*);
 int gnutls_x509_extract_certificate_subject_alt_name( const gnutls_datum*, int seq, char*, int*);
 int gnutls_x509_pkcs7_extract_certificate(const gnutls_datum * pkcs7_struct, int indx, char* certificate, int* certificate_size);
 int gnutls_x509_extract_certificate_pk_algorithm( const gnutls_datum * cert, int* bits);
+int gnutls_x509_extract_certificate_ca_status(const gnutls_datum * cert);
 int gnutls_x509_extract_key_pk_algorithm( const gnutls_datum * key);
 
 int gnutls_x509_verify_certificate( const gnutls_datum* cert_list, int cert_list_length, const gnutls_datum * CA_list, int CA_list_length, const gnutls_datum* CRL_list, int CRL_list_length);
@@ -504,12 +518,13 @@ int gnutls_pem_base64_decode_alloc( const char* header, const gnutls_datum *b64_
 #define GNUTLS_E_AGAIN -28
 #define GNUTLS_E_EXPIRED -29
 #define GNUTLS_E_DB_ERROR -30
-#define GNUTLS_E_PWD_ERROR -31
+#define GNUTLS_E_SRP_PWD_ERROR -31
 #define GNUTLS_E_INSUFICIENT_CREDENTIALS -32
 #define GNUTLS_E_INSUFICIENT_CRED GNUTLS_E_INSUFICIENT_CREDENTIALS
 
 #define GNUTLS_E_HASH_FAILED -33
-#define GNUTLS_E_PARSING_ERROR -34
+#define GNUTLS_E_BASE64_DECODING_ERROR -34
+
 #define	GNUTLS_E_MPI_PRINT_FAILED -35
 #define GNUTLS_E_REHANDSHAKE -37 /* GNUTLS_A_NO_RENEGOTIATION */
 #define GNUTLS_E_GOT_APPLICATION_DATA -38
@@ -539,7 +554,6 @@ int gnutls_pem_base64_decode_alloc( const char* header, const gnutls_datum *b64_
 #define GNUTLS_E_X509_UNKNOWN_SAN -62
 #define GNUTLS_E_DH_PRIME_UNACCEPTABLE -63
 #define GNUTLS_E_FILE_ERROR -64
-#define GNUTLS_E_ASCII_ARMOR_ERROR -65
 #define GNUTLS_E_ASN1_ELEMENT_NOT_FOUND -67
 #define GNUTLS_E_ASN1_IDENTIFIER_NOT_FOUND -68
 #define GNUTLS_E_ASN1_DER_ERROR -69
@@ -576,6 +590,7 @@ int gnutls_pem_base64_decode_alloc( const char* header, const gnutls_datum *b64_
 #define GNUTLS_E_PK_SIG_VERIFY_FAILED -89
 
 #define GNUTLS_E_ILLEGAL_SRP_USERNAME -90
+#define GNUTLS_E_SRP_PWD_PARSING_ERROR -91
 
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -250
 
