@@ -106,7 +106,7 @@ int gnutls_alert_send( gnutls_session session, gnutls_alert_level level, gnutls_
 
 	_gnutls_record_log( "REC: Sending Alert[%d|%d] - %s\n", data[0], data[1], gnutls_alert_get_name((int)data[1]));
 
-	if ( (ret = gnutls_send_int( session, GNUTLS_ALERT, -1, data, 2)) >= 0)
+	if ( (ret = _gnutls_send_int( session, GNUTLS_ALERT, -1, data, 2)) >= 0)
 		return 0;
 	else
 		return ret;
