@@ -1,5 +1,5 @@
 /*
- *      Copyright (C) 2000,2002 Nikos Mavroyanopoulos
+ * Copyright (C) 2000,2002 Nikos Mavroyanopoulos
  *
  * This file is part of GNUTLS.
  *
@@ -28,25 +28,68 @@
 /* Cred type mappings to KX algorithms */
 typedef struct {
 	gnutls_kx_algorithm algorithm;
-	gnutls_credentials_type type;
+	gnutls_credentials_type client_type;
+	gnutls_credentials_type server_type; /* The type of credentials a server
+					      * needs to set */
 } gnutls_cred_map;
 
 static const gnutls_cred_map cred_mappings[] = {
-	{ GNUTLS_KX_ANON_DH, GNUTLS_CRD_ANON    },
-	{ GNUTLS_KX_RSA,     GNUTLS_CRD_CERTIFICATE },
-	{ GNUTLS_KX_RSA_EXPORT,     GNUTLS_CRD_CERTIFICATE },
-	{ GNUTLS_KX_DHE_DSS, GNUTLS_CRD_CERTIFICATE },
-	{ GNUTLS_KX_DHE_RSA, GNUTLS_CRD_CERTIFICATE },
-	{ GNUTLS_KX_SRP,     GNUTLS_CRD_SRP     },
-	{ 0 }
+	{ GNUTLS_KX_ANON_DH, 	GNUTLS_CRD_ANON, 	GNUTLS_CRD_ANON    },
+	{ GNUTLS_KX_RSA,	GNUTLS_CRD_CERTIFICATE, GNUTLS_CRD_CERTIFICATE },
+	{ GNUTLS_KX_RSA_EXPORT, GNUTLS_CRD_CERTIFICATE, GNUTLS_CRD_CERTIFICATE },
+	{ GNUTLS_KX_DHE_DSS, 	GNUTLS_CRD_CERTIFICATE, GNUTLS_CRD_CERTIFICATE },
+	{ GNUTLS_KX_DHE_RSA, 	GNUTLS_CRD_CERTIFICATE, GNUTLS_CRD_CERTIFICATE },
+	{ GNUTLS_KX_SRP,     	GNUTLS_CRD_SRP,		GNUTLS_CRD_SRP     },
+	{ GNUTLS_KX_SRP_RSA,    GNUTLS_CRD_SRP,		GNUTLS_CRD_CERTIFICATE     },
+	{ GNUTLS_KX_SRP_DSS,    GNUTLS_CRD_SRP,		GNUTLS_CRD_CERTIFICATE     },
+	{ 0, 0, 0}
 };
 
 #define GNUTLS_KX_MAP_LOOP(b) \
         const gnutls_cred_map *p; \
-                for(p = cred_mappings; p->type != 0; p++) { b ; }
+                for(p = cred_mappings; p->algorithm != 0; p++) { b ; }
+
+#define GNUTLS_KX_MAP_ALG_LOOP_SERVER(a) \
+                        GNUTLS_KX_MAP_LOOP( if(p->server_type == type) { a; break; })
+
+#define GNUTLS_KX_MAP_ALG_LOOP_CLIENT(a) \
+                        GNUTLS_KX_MAP_LOOP( if(p->client_type == type) { a; break; })
+
+/* KX mappings to PK algorithms */
+typedef struct {
+	gnutls_kx_algorithm kx_algorithm;
+	gnutls_pk_algorithm pk_algorithm;
+	enum encipher_type encipher_type; /* CIPHER_ENCRYPT if this algorithm is to be used
+			    * for encryption, CIPHER_SIGN if signature only,
+			    * CIPHER_IGN if this does not apply at all.
+			    *
+			    * This is useful to certificate cipher suites, which check
+			    * against the certificate key usage bits.
+			    */
+} gnutls_pk_map;
+
+/* This table maps the Key exchange algorithms to
+ * the certificate algorithms. Eg. if we have
+ * RSA algorithm in the certificate then we can
+ * use GNUTLS_KX_RSA or GNUTLS_KX_DHE_RSA.
+ */
+static const gnutls_pk_map pk_mappings[] = {
+	{GNUTLS_KX_RSA, GNUTLS_PK_RSA, CIPHER_ENCRYPT},
+	{GNUTLS_KX_RSA_EXPORT, GNUTLS_PK_RSA, CIPHER_SIGN},
+	{GNUTLS_KX_DHE_RSA, GNUTLS_PK_RSA, CIPHER_SIGN},
+	{GNUTLS_KX_SRP_RSA, GNUTLS_PK_RSA, CIPHER_SIGN},
+	{GNUTLS_KX_DHE_DSS, GNUTLS_PK_DSA, CIPHER_SIGN},
+	{GNUTLS_KX_SRP_DSS, GNUTLS_PK_DSA, CIPHER_SIGN},
+	{0, 0, 0}
+};
+
+#define GNUTLS_PK_MAP_LOOP(b) \
+        const gnutls_pk_map *p; \
+                for(p = pk_mappings; p->kx_algorithm != 0; p++) { b ; }
+
+#define GNUTLS_PK_MAP_ALG_LOOP(a) \
+                        GNUTLS_PK_MAP_LOOP( if(p->kx_algorithm == kx_algorithm) { a; break; })
 
-#define GNUTLS_KX_MAP_ALG_LOOP(a) \
-                        GNUTLS_KX_MAP_LOOP( if(p->type == type) { a; break; })
 
 
 /* TLS Versions */
@@ -63,7 +106,7 @@ static const gnutls_version_entry sup_versions[] = {
 	{"SSL 3.0", GNUTLS_SSL3, 3, 0, 1},
 	{"TLS 1.0", GNUTLS_TLS1, 3, 1, 1},
 	{"UNKNOWN", GNUTLS_VERSION_UNKNOWN, 0, 0, 1},
-	{0}
+	{0, 0, 0, 0, 0}
 };
 
 #define GNUTLS_VERSION_LOOP(b) \
@@ -98,7 +141,7 @@ static const gnutls_cipher_entry algorithms[] = {
 	{"ARCFOUR 128", GNUTLS_CIPHER_ARCFOUR_128, 1, 16, CIPHER_STREAM, 0, 0 },
 	{"ARCFOUR 40", GNUTLS_CIPHER_ARCFOUR_40, 1, 5, CIPHER_STREAM, 0, 1 },
 	{"NULL", GNUTLS_CIPHER_NULL, 1, 0, CIPHER_STREAM, 0, 0 },
-	{0}
+	{0, 0, 0, 0, 0, 0, 0}
 };
 
 #define GNUTLS_LOOP(b) \
@@ -120,7 +163,7 @@ static const gnutls_hash_entry hash_algorithms[] = {
 	{"SHA", GNUTLS_MAC_SHA, 20},
 	{"MD5", GNUTLS_MAC_MD5, 16},
 	{"NULL", GNUTLS_MAC_NULL, 0},
-	{0}
+	{0, 0, 0}
 };
 
 #define GNUTLS_HASH_LOOP(b) \
@@ -148,7 +191,7 @@ gnutls_compression_entry _gnutls_compression_algorithms[MAX_COMP_METHODS] =
 	/* draft-ietf-tls-compression-02 */
 	GNUTLS_COMPRESSION_ENTRY(GNUTLS_COMP_ZLIB, 0x01, 15, 8, 3),
 #endif
-	{0}
+	{0, 0, 0, 0, 0, 0}
 };
 
 #define GNUTLS_COMPRESSION_LOOP(b) \
@@ -181,7 +224,10 @@ gnutls_kx_algo_entry _gnutls_kx_algorithms[MAX_KX_ALGOS] = {
 	{ "RSA EXPORT", GNUTLS_KX_RSA_EXPORT, &rsa_export_auth_struct },
 	{ "DHE RSA", GNUTLS_KX_DHE_RSA, &dhe_rsa_auth_struct },
 	{ "DHE DSS", GNUTLS_KX_DHE_DSS, &dhe_dss_auth_struct },
-	{0}
+	/* other algorithms are appended here by gnutls-extra
+	 * initialization function.
+	 */
+	{0, 0, 0}
 };
 
 #define GNUTLS_KX_LOOP(b) \
@@ -234,6 +280,14 @@ typedef struct {
 #define GNUTLS_SRP_SHA_RIJNDAEL_128_CBC_SHA { 0x00, 0x53 }
 #define GNUTLS_SRP_SHA_RIJNDAEL_256_CBC_SHA { 0x00, 0x56 }
 
+#define GNUTLS_SRP_SHA_RSA_3DES_EDE_CBC_SHA { 0x00, 0x51 }
+#define GNUTLS_SRP_SHA_DSS_3DES_EDE_CBC_SHA { 0x00, 0x52 }
+
+#define GNUTLS_SRP_SHA_RSA_RIJNDAEL_128_CBC_SHA { 0x00, 0x54 }
+#define GNUTLS_SRP_SHA_DSS_RIJNDAEL_128_CBC_SHA { 0x00, 0x55 }
+
+#define GNUTLS_SRP_SHA_RSA_RIJNDAEL_256_CBC_SHA { 0x00, 0x57 }
+#define GNUTLS_SRP_SHA_DSS_RIJNDAEL_256_CBC_SHA { 0x00, 0x58 }
 
 /** RSA 
  **/
@@ -316,6 +370,30 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 				  GNUTLS_CIPHER_RIJNDAEL_256_CBC, GNUTLS_KX_SRP,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_3DES_EDE_CBC_SHA,
+				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_SRP_DSS,
+				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
+
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_3DES_EDE_CBC_SHA,
+				  GNUTLS_CIPHER_3DES_CBC, GNUTLS_KX_SRP_RSA,
+				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
+
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_RIJNDAEL_128_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_KX_SRP_DSS,
+				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
+
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_RIJNDAEL_128_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL_128_CBC, GNUTLS_KX_SRP_RSA,
+				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
+
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_DSS_RIJNDAEL_256_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL_256_CBC, GNUTLS_KX_SRP_DSS,
+				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
+
+	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_SRP_SHA_RSA_RIJNDAEL_256_CBC_SHA,
+				  GNUTLS_CIPHER_RIJNDAEL_256_CBC, GNUTLS_KX_SRP_RSA,
+				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
+
 	/* DHE_DSS */
 	GNUTLS_CIPHER_SUITE_ENTRY(GNUTLS_DHE_DSS_ARCFOUR_SHA,
 				  GNUTLS_CIPHER_ARCFOUR_128, GNUTLS_KX_DHE_DSS,
@@ -375,7 +453,7 @@ static const gnutls_cipher_suite_entry cs_algorithms[] = {
 				  GNUTLS_CIPHER_TWOFISH_128_CBC, GNUTLS_KX_RSA,
 				  GNUTLS_MAC_SHA, GNUTLS_TLS1),
 
-	{0}
+	{0, {{0,0}}, 0, 0, 0, 0}
 };
 
 #define GNUTLS_CIPHER_SUITE_LOOP(b) \
@@ -646,6 +724,7 @@ MOD_AUTH_STRUCT *_gnutls_kx_auth_struct(gnutls_kx_algorithm algorithm)
 
 }
 
+
 inline int _gnutls_kx_priority(gnutls_session session, gnutls_kx_algorithm algorithm)
 {
 	unsigned int i;
@@ -805,18 +884,26 @@ int ret=0;
 }
 
 /* Type to KX mappings */
-gnutls_kx_algorithm _gnutls_map_kx_get_kx(gnutls_credentials_type type)
+gnutls_kx_algorithm _gnutls_map_kx_get_kx(gnutls_credentials_type type, int server)
 {
 	gnutls_kx_algorithm ret = -1;
 
-	GNUTLS_KX_MAP_ALG_LOOP(ret = p->algorithm);
+	if (server) {
+		GNUTLS_KX_MAP_ALG_LOOP_SERVER(ret = p->algorithm);
+	} else {
+		GNUTLS_KX_MAP_ALG_LOOP_SERVER(ret = p->algorithm);
+	}
 	return ret;
 }
 
-gnutls_credentials_type _gnutls_map_kx_get_cred(gnutls_kx_algorithm algorithm)
+gnutls_credentials_type _gnutls_map_kx_get_cred(gnutls_kx_algorithm algorithm, int server)
 {
 	gnutls_credentials_type ret = -1;
-	GNUTLS_KX_MAP_LOOP(if (p->algorithm==algorithm) ret = p->type);
+	if (server) {
+		GNUTLS_KX_MAP_LOOP(if (p->algorithm==algorithm) ret = p->server_type);
+	} else {
+		GNUTLS_KX_MAP_LOOP(if (p->algorithm==algorithm) ret = p->client_type);
+	}
 
 	return ret;
 }
@@ -1231,7 +1318,7 @@ _gnutls_supported_compression_methods(gnutls_session session, uint8 ** comp)
   * @type: is a certificate type
   *
   * Returns a string that contains the name 
-  * of the specified MAC algorithm.
+  * of the specified certificate type.
   **/
 const char *gnutls_certificate_type_get_name( gnutls_certificate_type type)
 {
@@ -1242,3 +1329,27 @@ const char *gnutls_certificate_type_get_name( gnutls_certificate_type type)
 
 	return ret;
 }
+
+/* returns the gnutls_pk_algorithm which is compatible with
+ * the given gnutls_kx_algorithm.
+ */
+gnutls_pk_algorithm _gnutls_map_pk_get_pk(gnutls_kx_algorithm kx_algorithm)
+{
+	gnutls_pk_algorithm ret = -1;
+
+	GNUTLS_PK_MAP_ALG_LOOP(ret = p->pk_algorithm);
+	return ret;
+}
+
+/* Returns the encipher type for the the given key exchange algorithm.
+ * That one of CIPHER_ENCRYPT, CIPHER_SIGN, CIPHER_IGN.
+ *
+ * ex. GNUTLS_KX_RSA requires a certificate able to encrypt... so returns CIPHER_ENCRYPT.
+ */
+enum encipher_type _gnutls_kx_encipher_type(gnutls_kx_algorithm kx_algorithm)
+{
+	int ret = CIPHER_IGN;
+	GNUTLS_PK_MAP_ALG_LOOP(ret = p->encipher_type);
+	return ret;
+
+}
