@@ -18,6 +18,6 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-const GNUTLS_MPI* _gnutls_get_rsa_params(GNUTLS_RSA_PARAMS, int bits);
-int _gnutls_peers_cert_less_512( GNUTLS_STATE state);
+const GNUTLS_MPI* _gnutls_get_rsa_params(gnutls_rsa_params, int bits);
+int _gnutls_peers_cert_less_512( gnutls_session session);
 
