@@ -576,7 +576,7 @@ static gnutls_x509_subject_alt_name _find_type( char* str_type) {
 }
 
 /**
-  * gnutls_x509_extract_certificate_subject_alt_name - This function returns the peer's alt name, if any
+  * gnutls_x509_extract_certificate_subject_alt_name - This function returns the certificate's alternative name, if any
   * @cert: should contain an X.509 DER encoded certificate
   * @seq: specifies the sequence number of the alt name (0 for the first one, 1 for the second etc.)
   * @ret: is the place where the alternative name will be copied to
@@ -687,6 +687,76 @@ int gnutls_x509_extract_certificate_subject_alt_name(const gnutls_datum * cert,
 	return type;
 }
 
+/**
+  * gnutls_x509_extract_certificate_ca_status - This function returns the certificate CA status
+  * @cert: should contain an X.509 DER encoded certificate
+  *
+  * This function will return certificates CA status, by reading the 
+  * basicConstraints X.509 extension. If the certificate is a CA a positive
+  * value will be returned, or zero if the certificate does not have
+  * CA flag set. 
+  *
+  * A negative value may be returned in case of parsing error.
+  * If the certificate does not contain the basicConstraints extension
+  * GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE will be returned.
+  *
+  **/
+int gnutls_x509_extract_certificate_ca_status(const gnutls_datum * cert)
+{
+	int result;
+	gnutls_datum basicConstraints;
+	ASN1_TYPE c2;
+	char str[128];
+	char ext_data[256];
+	int len;
+
+	if ((result =
+	     _gnutls_get_extension(cert, "2 5 29 19", &basicConstraints)) < 0) {
+	     	gnutls_assert();
+		return result;
+	}
+
+	if (basicConstraints.size == 0 || basicConstraints.data==NULL) {
+		gnutls_assert();
+		return GNUTLS_E_REQUESTED_DATA_NOT_AVAILABLE;
+	}
+
+	if ((result=_gnutls_asn1_create_element
+	    (_gnutls_get_pkix(), "PKIX1.BasicConstraints", &c2, "bc"))
+	    != ASN1_SUCCESS) {
+		gnutls_assert();
+		_gnutls_free_datum( &basicConstraints);
+		return _gnutls_asn2err(result);
+	}
+
+	result = asn1_der_decoding(&c2, basicConstraints.data, basicConstraints.size, NULL);
+	_gnutls_free_datum( &basicConstraints);
+
+
+	if (result != ASN1_SUCCESS) {
+		/* couldn't decode DER */
+
+		_gnutls_log("X509_auth: Decoding error %d\n", result);
+		gnutls_assert();
+		asn1_delete_structure(&c2);
+		return _gnutls_asn2err(result);
+	}
+
+	len = sizeof(str) - 1;
+	result = asn1_read_value(c2, "bc.cA", str, &len);
+	asn1_delete_structure(&c2);
+
+	if (result != ASN1_SUCCESS) {
+		gnutls_assert();
+		return _gnutls_asn2err(result);
+	}        
+
+	if (strcmp(str, "TRUE") == 0)
+		return 1; /* CA */
+	else
+		return 0; /* not a CA */
+}
+
 /**
   * gnutls_x509_extract_certificate_activation_time - This function returns the peer's certificate activation time
   * @cert: should contain an X.509 DER encoded certificate
@@ -1218,7 +1288,7 @@ static int parse_pem_cert_mem( gnutls_cert** cert_list, int* ncerts,
 
 		if (siz2 < 0) {
 			gnutls_assert();
-			return GNUTLS_E_PARSING_ERROR;
+			return GNUTLS_E_BASE64_DECODING_ERROR;
 		}
 
 		ret = parse_pkcs7_cert_mem( cert_list, ncerts, b64,
@@ -1236,7 +1306,7 @@ static int parse_pem_cert_mem( gnutls_cert** cert_list, int* ncerts,
 
 	if (ptr == NULL) {
 		gnutls_assert();
-		return GNUTLS_E_PARSING_ERROR;
+		return GNUTLS_E_BASE64_DECODING_ERROR;
 	}
 	siz = strlen( ptr);
 
@@ -1249,7 +1319,7 @@ static int parse_pem_cert_mem( gnutls_cert** cert_list, int* ncerts,
 
 		if (siz2 < 0) {
 			gnutls_assert();
-			return GNUTLS_E_PARSING_ERROR;
+			return GNUTLS_E_BASE64_DECODING_ERROR;
 		}
 
 		*cert_list =
@@ -1474,14 +1544,14 @@ static int read_key_mem(gnutls_certificate_credentials res, const char *key, int
 			key = strstr( key, PEM_KEY_DSA_SEP);
 			if (key == NULL) {
 				gnutls_assert();
-				return GNUTLS_E_PARSING_ERROR;
+				return GNUTLS_E_BASE64_DECODING_ERROR;
 			}			key_size = strlen( key);
 		} else {
 			pk = GNUTLS_PK_RSA;
 			key = strstr( key, PEM_KEY_RSA_SEP);
 			if (key == NULL) {
 				gnutls_assert();
-				return GNUTLS_E_PARSING_ERROR;
+				return GNUTLS_E_BASE64_DECODING_ERROR;
 			}
 			key_size = strlen( key);
 		}
@@ -1491,7 +1561,7 @@ static int read_key_mem(gnutls_certificate_credentials res, const char *key, int
 
 		if (ret < 0) {
 			gnutls_assert();
-			return GNUTLS_E_PARSING_ERROR;
+			return GNUTLS_E_BASE64_DECODING_ERROR;
 		}
 
 		tmp.data = b64;
@@ -2861,6 +2931,82 @@ int str_length, j, i;
 	return buffer;
 }
 
+/* defines needed in *dn_string functions
+ */
+#define STR_APPEND(y) if (_gnutls_string_append_str( &str, y) < 0) { \
+		_gnutls_string_clear( &str); \
+		gnutls_assert(); \
+		return GNUTLS_E_MEMORY_ERROR; \
+	}
+#define PRINTX( x, y) \
+   if (y[0]!=0) { \
+      if (i==0) i=1; else { STR_APPEND( ","); } \
+      STR_APPEND( x); \
+      STR_APPEND( "="); \
+      STR_APPEND( str_escape(y, str_buffer, sizeof(str_buffer))); \
+   }
+
+
+
+/**
+  * gnutls_x509_extract_dn_string - This function parses an RDN sequence and returns a string
+  * @idn: should contain a DER encoded RDN sequence
+  * @buf: a pointer to a structure to hold the peer's name
+  * @sizeof_buf: holds the size of 'buf'
+  *
+  * This function will return the name of the given RDN sequence.
+  * The name will be in the form "C=xxxx,O=yyyy,CN=zzzz" as described 
+  * in RFC2253.
+  *
+  * Returns GNUTLS_E_SHORT_MEMORY_BUFFER if the provided buffer is not long enough,
+  * and 0 on success.
+  *
+  **/
+int gnutls_x509_extract_dn_string(const gnutls_datum * idn, 
+	char *buf, unsigned int sizeof_buf)
+{
+gnutls_x509_dn dn;
+int ret, i;
+gnutls_string str;
+char str_buffer[256];
+
+   if (buf == NULL || sizeof_buf == 0) {
+      return GNUTLS_E_INVALID_REQUEST;
+   }
+   
+   buf[0] = 0;
+
+  ret = gnutls_x509_extract_certificate_dn(idn, &dn);
+  if (ret < 0) {
+  	gnutls_assert();
+  	return ret;
+  }
+
+   _gnutls_string_init( &str, gnutls_malloc, gnutls_realloc, gnutls_free);
+
+   i = 0;
+   PRINTX( "CN", dn.common_name);
+   PRINTX( "E", dn.email);
+   PRINTX( "OU", dn.organizational_unit_name);
+   PRINTX( "O", dn.organization);
+   PRINTX( "L", dn.locality_name);
+   PRINTX( "ST", dn.state_or_province_name);
+   PRINTX( "C", dn.country);
+ 
+   if (str.length >= sizeof_buf) {
+        _gnutls_string_clear( &str);
+	return GNUTLS_E_SHORT_MEMORY_BUFFER;
+   }
+   
+   memcpy( buf, str.data, str.length);
+   buf[str.length] = 0;
+
+   _gnutls_string_clear( &str);
+
+   return 0;
+
+}
+
 /**
   * gnutls_x509_extract_certificate_dn_string - This function returns the certificate's distinguished name
   * @cert: should contain an X.509 DER encoded certificate
@@ -2891,19 +3037,6 @@ int gnutls_x509_extract_certificate_dn_string(char *buf, unsigned int sizeof_buf
 
    _gnutls_string_init( &str, gnutls_malloc, gnutls_realloc, gnutls_free);
 
-#define STR_APPEND(y) if (_gnutls_string_append_str( &str, y) < 0) { \
-		_gnutls_string_clear( &str); \
-		gnutls_assert(); \
-		return GNUTLS_E_MEMORY_ERROR; \
-	}
-#define PRINTX( x, y) \
-   if (y[0]!=0) { \
-      if (i==0) i=1; else { STR_APPEND( ","); } \
-      STR_APPEND( x); \
-      STR_APPEND( "="); \
-      STR_APPEND( str_escape(y, str_buffer, sizeof(str_buffer))); \
-   }
-
    if (!issuer)
       ret = gnutls_x509_extract_certificate_dn(cert, &dn);
    else
