@@ -3,18 +3,16 @@
 typedef struct {
 	char* username;
 	
-	opaque *salt;
-	int salt_size;
-	
-	MPI v;
-	MPI g;
-	MPI n;
-} GNUTLS_SRP_PWD_ENTRY;
+	gnutls_datum salt;
+	gnutls_datum v;
+	gnutls_datum g;
+	gnutls_datum n;
+} SRP_PWD_ENTRY;
 
 /* this is localy alocated. It should be freed using the provided function */
-GNUTLS_SRP_PWD_ENTRY *_gnutls_srp_pwd_read_entry( gnutls_session state, char* username, int* err);
-void _gnutls_srp_clear_pwd_entry( GNUTLS_SRP_PWD_ENTRY * entry);
-GNUTLS_SRP_PWD_ENTRY* _gnutls_randomize_pwd_entry(void);
+SRP_PWD_ENTRY *_gnutls_srp_pwd_read_entry( gnutls_session state, char* username, int* err);
+void _gnutls_srp_entry_free( SRP_PWD_ENTRY * entry);
+SRP_PWD_ENTRY* _gnutls_randomize_pwd_entry(void);
 int _gnutls_sbase64_encode(uint8 * data, size_t data_size, uint8 ** result);
 int _gnutls_sbase64_decode(uint8 * data, size_t data_size, uint8 ** result);
 
