@@ -119,9 +119,6 @@ void init_global_tls_stuff(void);
 #define DEFAULT_PGP_CERTFILE "openpgp/cli_pub.asc"
 #define DEFAULT_PGP_KEYRING "openpgp/cli_ring.gpg"
 
-#define DEFAULT_SRP_USERNAME "test"
-#define DEFAULT_SRP_PASSWD "test"
-
 /* initializes a gnutls_session with some defaults.
  */
 static gnutls_session init_tls_session( const char* hostname)
@@ -145,10 +142,10 @@ static gnutls_session init_tls_session( const char* hostname)
 
    gnutls_dh_set_prime_bits(session, 512);
 
-   gnutls_cred_set(session, GNUTLS_CRD_ANON, anon_cred);
+   gnutls_credentials_set(session, GNUTLS_CRD_ANON, anon_cred);
    if (srp_username != NULL)
-      gnutls_cred_set(session, GNUTLS_CRD_SRP, cred);
-   gnutls_cred_set(session, GNUTLS_CRD_CERTIFICATE, xcred);
+      gnutls_credentials_set(session, GNUTLS_CRD_SRP, cred);
+   gnutls_credentials_set(session, GNUTLS_CRD_CERTIFICATE, xcred);
 
    /* send the fingerprint */
    if (fingerprint != 0)
@@ -366,9 +363,9 @@ int main(int argc, char **argv)
 
 
    if (srp_username != NULL)
-      gnutls_srp_free_client_cred(cred);
-   gnutls_certificate_free_cred(xcred);
-   gnutls_anon_free_client_cred(anon_cred);
+      gnutls_srp_free_client_credentials(cred);
+   gnutls_certificate_free_credentials(xcred);
+   gnutls_anon_free_client_credentials(anon_cred);
 
    gnutls_global_deinit();
 
@@ -428,13 +425,9 @@ void gaa_parser(int argc, char **argv)
 
    if (info.srp_passwd != NULL)
       srp_passwd = info.srp_passwd;
-   else
-      srp_passwd = DEFAULT_SRP_PASSWD;
 
    if (info.srp_username != NULL)
       srp_username = info.srp_username;
-   else
-      srp_username = DEFAULT_SRP_USERNAME;
 #else
    srp_username = info.srp_username;
    srp_passwd = info.srp_passwd;
@@ -456,83 +449,13 @@ void gaa_parser(int argc, char **argv)
    else
       hostname = info.rest_args;
 
-   if (info.proto != NULL && info.nproto > 0) {
-      for (j = i = 0; i < info.nproto; i++) {
-	 if (strncasecmp(info.proto[i], "SSL", 3) == 0)
-	    protocol_priority[j++] = GNUTLS_SSL3;
-	 if (strncasecmp(info.proto[i], "TLS", 3) == 0)
-	    protocol_priority[j++] = GNUTLS_TLS1;
-      }
-      protocol_priority[j] = 0;
-   }
+   parse_protocols( info.proto, info.nproto, protocol_priority);
+   parse_ciphers( info.ciphers, info.nciphers, cipher_priority);
+   parse_macs( info.macs, info.nmacs, mac_priority);
+   parse_ctypes( info.ctype, info.nctype, cert_type_priority);
+   parse_kx( info.kx, info.nkx, kx_priority);
+   parse_comp( info.comp, info.ncomp, comp_priority);
 
-   if (info.ciphers != NULL && info.nciphers > 0) {
-      for (j = i = 0; i < info.nciphers; i++) {
-	 if (strncasecmp(info.ciphers[i], "RIJ", 3) == 0)
-	    cipher_priority[j++] = GNUTLS_CIPHER_RIJNDAEL_128_CBC;
-	 if (strncasecmp(info.ciphers[i], "TWO", 3) == 0)
-	    cipher_priority[j++] = GNUTLS_CIPHER_TWOFISH_128_CBC;
-	 if (strncasecmp(info.ciphers[i], "3DE", 3) == 0)
-	    cipher_priority[j++] = GNUTLS_CIPHER_3DES_CBC;
-	 if (strcasecmp(info.ciphers[i], "ARCFOUR-40") == 0)
-	    cipher_priority[j++] = GNUTLS_CIPHER_ARCFOUR_40;
-	 if (strcasecmp(info.ciphers[i], "ARCFOUR") == 0)
-	    cipher_priority[j++] = GNUTLS_CIPHER_ARCFOUR_128;
-	 if (strncasecmp(info.ciphers[i], "NUL", 3) == 0)
-	    cipher_priority[j++] = GNUTLS_CIPHER_NULL;
-      }
-      cipher_priority[j] = 0;
-   }
-
-   if (info.macs != NULL && info.nmacs > 0) {
-      for (j = i = 0; i < info.nmacs; i++) {
-	 if (strncasecmp(info.macs[i], "MD5", 3) == 0)
-	    mac_priority[j++] = GNUTLS_MAC_MD5;
-	 if (strncasecmp(info.macs[i], "SHA", 3) == 0)
-	    mac_priority[j++] = GNUTLS_MAC_SHA;
-      }
-      mac_priority[j] = 0;
-   }
-
-   if (info.ctype != NULL && info.nctype > 0) {
-      for (j = i = 0; i < info.nctype; i++) {
-	 if (strncasecmp(info.ctype[i], "OPE", 3) == 0)
-	    cert_type_priority[j++] = GNUTLS_CRT_OPENPGP;
-	 if (strncasecmp(info.ctype[i], "X", 1) == 0)
-	    cert_type_priority[j++] = GNUTLS_CRT_X509;
-      }
-      cert_type_priority[j] = 0;
-   }
-
-   if (info.kx != NULL && info.nkx > 0) {
-      for (j = i = 0; i < info.nkx; i++) {
-	 if (strncasecmp(info.kx[i], "SRP", 3) == 0)
-	    kx_priority[j++] = GNUTLS_KX_SRP;
-	 if (strcasecmp(info.kx[i], "RSA") == 0)
-	    kx_priority[j++] = GNUTLS_KX_RSA;
-	 if (strcasecmp(info.kx[i], "RSA-EXPORT") == 0)
-	    kx_priority[j++] = GNUTLS_KX_RSA_EXPORT;
-	 if (strncasecmp(info.kx[i], "DHE-RSA", 7) == 0)
-	    kx_priority[j++] = GNUTLS_KX_DHE_RSA;
-	 if (strncasecmp(info.kx[i], "DHE-DSS", 7) == 0)
-	    kx_priority[j++] = GNUTLS_KX_DHE_DSS;
-	 if (strncasecmp(info.kx[i], "ANON", 4) == 0)
-	    kx_priority[j++] = GNUTLS_KX_ANON_DH;
-      }
-      kx_priority[j] = 0;
-   }
-
-   if (info.comp != NULL && info.ncomp > 0) {
-      for (j = i = 0; i < info.ncomp; i++) {
-	 if (strncasecmp(info.comp[i], "NUL", 3) == 0)
-	    comp_priority[j++] = GNUTLS_COMP_NULL;
-	 if (strncasecmp(info.comp[i], "ZLI", 3) == 0)
-	    comp_priority[j++] = GNUTLS_COMP_ZLIB;
-	 if (strncasecmp(info.comp[i], "LZO", 3) == 0)
-	    comp_priority[j++] = GNUTLS_COMP_LZO;
-      }
-      comp_priority[j] = 0;
-   }
 
 }
 
@@ -662,7 +585,7 @@ int ret;
    }
 
    /* X509 stuff */
-   if (gnutls_certificate_allocate_cred(&xcred) < 0) {
+   if (gnutls_certificate_allocate_credentials(&xcred) < 0) {
       fprintf(stderr, "Certificate allocation memory error\n");
       exit(1);
    }
@@ -720,14 +643,17 @@ int ret;
 
    /* SRP stuff */
    if (srp_username != NULL) {
-      if (gnutls_srp_allocate_client_cred(&cred) < 0) {
+      if (gnutls_srp_allocate_client_credentials(&cred) < 0) {
 	 fprintf(stderr, "SRP authentication error\n");
       }
-      gnutls_srp_set_client_cred(cred, srp_username, srp_passwd);
+
+      if ((ret=gnutls_srp_set_client_credentials(cred, srp_username, srp_passwd)) < 0) {
+	 fprintf(stderr, "SRP credentials set error [%d]\n", ret);
+      }
    }
 
    /* ANON stuff */
-   if (gnutls_anon_allocate_client_cred(&anon_cred) < 0) {
+   if (gnutls_anon_allocate_client_credentials(&anon_cred) < 0) {
       fprintf(stderr, "Anonymous authentication error\n");
    }
 }
